@@ -1,3 +1,6 @@
+mod error_3rd;
+mod error_std;
+
 use std::{
     convert::Infallible,
     error::Error,
@@ -7,10 +10,7 @@ use std::{
 };
 use yggdrasil_shared::records::Url;
 
-mod error_3rd;
-mod error_custom;
-mod error_std;
-
+/// All result about notedown
 pub type Result<T> = std::result::Result<T, NoteError>;
 
 #[derive(Debug)]
@@ -32,8 +32,8 @@ pub enum NoteErrorKind {
     },
     /// A forbidden cst_node encountered
     Unreachable,
-    /* #[error(transparent)]
-     * UnknownError(#[from] anyhow::Error), */
+    // #[error(transparent)]
+    // UnknownError(#[from] anyhow::Error),
 }
 
 impl NoteError {
