@@ -1,20 +1,17 @@
+mod collections;
 mod methods;
 mod traits;
 mod typing;
 
-pub use self::typing::ValueType;
+pub use self::{collections::*, typing::ValueType};
 use crate::nodes::Literal;
 use indexmap::{IndexMap, IndexSet};
 use num::{BigInt, BigUint};
 use rust_decimal::Decimal;
 use std::collections::{BTreeMap, BTreeSet};
 
-/// Sparse representation of the array, the subscript can be any non-zero integer
-pub type SparseArray = BTreeMap<BigUint, Literal<Value>>;
 /// Ordered set of values
 pub type OrderedSet = IndexSet<Literal<Value>>;
-/// Ordered map of key value pairs
-pub type OrderedMap = IndexMap<String, Literal<Value>>;
 
 ///
 #[derive(Clone, Debug, Eq, PartialEq)]
@@ -32,9 +29,9 @@ pub enum Value {
     /// Ordered set of values
     Set(OrderedSet),
     /// Array of values
-    Array(SparseArray),
+    Array(Box<SparseArray>),
     /// Ordered map of key value pairs
-    Object(OrderedMap),
+    Object(Box<OrderedMap>),
 }
 
 impl Value {
